# -*- coding: utf-8 -*- # Generated by Django 1.11.7 on 2017-12-04 10:18
from __future__ import unicode_literals

import datetime
from django.db import migrations, models
import django.db.models.deletion
import uuid


def create_system_account(apps, schema_editor):
    Account = apps.get_model('silverstrike', 'Account')
    Account.objects.create(name='System Account', account_type=3)


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('account_type', models.IntegerField(choices=[(1, 'Personal'), (2, 'Foreign'), (3, 'System')], default=1)),
                ('active', models.BooleanField(default=True)),
                ('last_modified', models.DateTimeField(auto_now=True)),
                ('show_on_dashboard', models.BooleanField(default=False)),
            ],
            options={
                'ordering': ['-active', 'name'],
            },
        ),
        migrations.CreateModel(
            name='Budget',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('month', models.DateField()),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=10)),
            ],
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('last_modified', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name_plural': 'categories',
            },
        ),
        migrations.CreateModel(
            name='ImportConfiguration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('headers', models.BooleanField(help_text='First line contains headers')),
                ('dateformat', models.CharField(max_length=32)),
                ('config', models.TextField()),
                ('default_account', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='silverstrike.Account')),
            ],
        ),
        migrations.CreateModel(
            name='ImportFile',
            fields=[
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('file', models.FileField(upload_to='imports')),
            ],
        ),
        migrations.CreateModel(
            name='RecurringTransaction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=64)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=10)),
                ('date', models.DateField()),
                ('recurrence', models.IntegerField(choices=[(0, 'Disabled'), (1, 'Weekly'), (2, 'Monthly'), (3, 'Yearly')])),
                ('transaction_type', models.IntegerField(choices=[(1, 'Deposit'), (2, 'Withdrawl'), (3, 'Transfer')])),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='silverstrike.Category')),
                ('dst', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='opposing_recurring_transactions', to='silverstrike.Account')),
                ('src', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='silverstrike.Account')),
            ],
            options={
                'ordering': ['date'],
            },
        ),
        migrations.CreateModel(
            name='Split',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=64)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=10)),
                ('date', models.DateField(default=datetime.date.today)),
                ('account', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='incoming_transactions', to='silverstrike.Account')),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='splits', to='silverstrike.Category')),
                ('opposing_account', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='outgoing_transactions', to='silverstrike.Account')),
            ],
            options={
                'ordering': ['-date', 'title'],
            },
        ),
        migrations.CreateModel(
            name='Transaction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=64)),
                ('date', models.DateField(default=datetime.date.today)),
                ('notes', models.TextField(blank=True, null=True)),
                ('transaction_type', models.IntegerField(choices=[(1, 'Deposit'), (2, 'Withdrawl'), (3, 'Transfer'), (4, 'Reconcile')])),
                ('recurrence', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='recurrences', to='silverstrike.RecurringTransaction')),
            ],
            options={
                'ordering': ['-date', 'title'],
            },
        ),
        migrations.AddField(
            model_name='split',
            name='transaction',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='splits', to='silverstrike.Transaction'),
        ),
        migrations.AddField(
            model_name='budget',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='silverstrike.Category'),
        ),
        migrations.RunPython(create_system_account),
    ]


